pub enum Propagation {
Down,
Up,
DownUp,
Fall,
Direct,
All,
}Expand description
Determines how the event propagates through the tree
Variants
Down
Events propagate down the tree to the target entity, e.g. from grand-parent to parent to child (target)
Up
Events propagate up the tree to the target entity, e.g. from child (target) to parent to grand-parent
DownUp
Events propagate down the tree to the target entity and then back up to the root
Fall
Events propagate from the target entity to all entities below but on the same branch
Direct
Events propagate directly to the target entity and to no others
All
Events propagate to all entities in the tree